@@ -11,11 +11,9 @@ BT_REGISTER_NODES(factory)
 BT::NodeStatus MoveBaseAction::tick()
 {
     Pose2D goal;
-    if (getParam<Pose2D>("goal", goal) == false)
+    if ( !getInput<Pose2D>("goal", goal))
     {
-        auto default_goal_value = requiredNodeParameters().at("goal");
-        // use the convertFromString function
-        goal = BT::convertFromString<Pose2D>(default_goal_value);
+        throw BT::RuntimeError("missing required input [goal]");
     }
 
     printf("[ MoveBase: STARTED ]. goal: x=%.f y=%.1f theta=%.2f\n", goal.x, goal.y, goal.theta);
@@ -23,14 +21,16 @@ BT::NodeStatus MoveBaseAction::tick()
     _halt_requested.store(false);
     int count = 0;
 
-    // "compute" for 250 milliseconds or until _halt_requested is true
+    // Pretend that "computing" takes 250 milliseconds.
+    // It is up to you to check periodicall _halt_requested and interrupt
+    // this tick() if it is true.
     while (!_halt_requested && count++ < 25)
     {
         SleepMS(10);
     }
 
     std::cout << "[ MoveBase: FINISHED ]" << std::endl;
-    return _halt_requested ? BT::NodeStatus::SUCCESS : BT::NodeStatus::SUCCESS;
+    return _halt_requested ? BT::NodeStatus::FAILURE : BT::NodeStatus::SUCCESS;
 }
 
 void MoveBaseAction::halt()
